Learn R Programming

mctq (version 0.3.2)

mctq-package: mctq: Tools to Process the Munich ChronoType Questionnaire (MCTQ)

Description

logo

A complete toolkit to process the Munich ChronoType Questionnaire (MCTQ) for its three versions (standard, micro, and shift). MCTQ is a quantitative and validated tool to assess chronotypes using peoples' sleep behavior, originally presented by Till Roenneberg, Anna Wirz-Justice, and Martha Merrow (2003, tools:::Rd_expr_doi("10.1177/0748730402239679")).

Arguments

Author

Maintainer: Daniel Vartanian danvartan@gmail.com (ORCID) [conceptor, copyright holder]

Other contributors:

See Also